# -*- coding: utf-8 -*-
from themoviedb.routes_sync._base import Base  # noqa: F401
from themoviedb.routes_sync.authentication import Authentication  # noqa: F401
from themoviedb.routes_sync.certifications import Certifications  # noqa: F401
from themoviedb.routes_sync.collections import Collection  # noqa: F401
from themoviedb.routes_sync.companies import Company  # noqa: F401
from themoviedb.routes_sync.credit import Credit  # noqa: F401
from themoviedb.routes_sync.discover import Discover  # noqa: F401
from themoviedb.routes_sync.episode_groups import EpisodeGroup  # noqa: F401
from themoviedb.routes_sync.episodes import Episode  # noqa: F401
from themoviedb.routes_sync.find import Find  # noqa: F401
from themoviedb.routes_sync.genres import Genres  # noqa: F401
from themoviedb.routes_sync.guest import Guest  # noqa: F401
from themoviedb.routes_sync.keywords import Keyword  # noqa: F401
from themoviedb.routes_sync.movies import Movie, Movies  # noqa: F401
from themoviedb.routes_sync.network import Network  # noqa: F401
from themoviedb.routes_sync.people import People, Person  # noqa: F401
from themoviedb.routes_sync.reviews import Review  # noqa: F401
from themoviedb.routes_sync.search import Search  # noqa: F401
from themoviedb.routes_sync.seasons import Season  # noqa: F401
from themoviedb.routes_sync.trending import Trending  # noqa: F401
from themoviedb.routes_sync.tv import TV, TVs  # noqa: F401
from themoviedb.routes_sync.watch_providers import WatchProviders  # noqa: F401
